==> ui-react-1.0.84.tgz: package/esm/Menu/Menu.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["open", "openDefault", "name", "label", "menuItems", "arrow", "anchor", "anchorElement", "autoSelect", "autoSelectOnBlur", "resetKeyboardNavigation", "closeOnClickAway", "include", "includeParentQueries", "includeQueries", "ignoreNonExisting", "onSelect", "onOpen", "onClose", "ListProps", "ModalProps", "WrapperProps", "ClickListenerProps", "className", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { is, isEnvironment } from '@onesy/utils';
import { style as styleMethod, classNames, useOnesyTheme } from '@onesy/style-react';
import ListElement from '../List';
import TooltipElement from '../Tooltip';
import ClickListenerElement from '../ClickListener';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {}
}), {
  name: 'onesy-Menu'
});
export const MENUS = {
  open: [],
  priority: value => MENUS.open[MENUS.open.length - 1] === value,
  add: value => {
    const index = MENUS.open.findIndex(item => item === value);
    if (index === -1) MENUS.open.push(value);
    MENUS.open = MENUS.open.filter(Boolean);
  },
  remove: value => {
    const index = MENUS.open.findIndex(item => item === value);
    if (index > -1) MENUS.open.splice(index, 1);
    MENUS.open = MENUS.open.filter(Boolean);
  }
};
const Menu = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyMenu?.props?.default), props_), [props_]);
  const List = React.useMemo(() => theme?.elements?.List || ListElement, [theme]);
  const Tooltip = React.useMemo(() => theme?.elements?.Tooltip || TooltipElement, [theme]);
  const ClickListener = React.useMemo(() => theme?.elements?.ClickListener || ClickListenerElement, [theme]);
  const {
      open: open_,
      openDefault,
      name,
      label,
      menuItems,
      arrow,
      anchor,
      anchorElement,
      autoSelect,
      autoSelectOnBlur,
      resetKeyboardNavigation = false,
      closeOnClickAway = true,
      include = [],
      includeParentQueries = [],
      includeQueries = [],
      ignoreNonExisting,
      onSelect,
      onOpen: onOpen_,
      onClose: onClose_,
      ListProps,
      ModalProps,
      WrapperProps: WrapperProps_,
      ClickListenerProps,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const id = React.useId();
  const [open, setOpen] = React.useState(openDefault !== undefined ? openDefault : open_);
  const [preselected, setPreselected] = React.useState();
  const refs = {
    root: React.useRef(undefined),
    id: React.useRef(undefined),
    main: React.useRef(undefined),
    props: React.useRef(undefined),
    preselected: React.useRef(undefined),
    include: React.useRef([]),
    menuClassName: React.useRef(`a-${new Date().getTime()}`)
  };
  refs.id.current = id;
  refs.preselected.current = preselected;
  refs.props.current = props;
  React.useEffect(() => {
    if (open) {
      MENUS.add(refs.id.current);
      if (autoSelect) {
        const values = React.Children.toArray(refs.props.current.children).map((item, index) => (item.props?.button || item.props?.href) && !item.props?.disabled ? index : undefined).filter(item => is('number', item));
        setPreselected(values[0]);
      }
    }
    const onKeyDown = event => {
      if (refs.props.current.open && MENUS.priority(refs.id.current)) {
        const values = React.Children.toArray(refs.props.current.children).map((item, index) => (item.props?.button || item.props?.href) && !item.props?.disabled ? index : undefined).filter(item => is('number', item));
        switch (event.key) {
          case 'ArrowUp':
            event.preventDefault();
            return setPreselected(() => {
              let value = refs.preselected.current;
              const index = values.findIndex(item_ => item_ === value);
              if (index === -1) value = values[values.length - 1];else if (index > 0) value = values[index - 1];else if (refs.props.current.resetKeyboardNavigation) value = values[values.length - 1];
              return value;
            });
          case 'ArrowDown':
            event.preventDefault();
            return setPreselected(() => {
              let value = refs.preselected.current;
              const index = values.findIndex(item_ => item_ === value);
              if (index === -1) value = values[0];else if (index < values.length - 1) value = values[index + 1];else if (refs.props.current.resetKeyboardNavigation) value = values[0];
              return value;
            });
          case 'Escape':
            event.preventDefault();
            return onClose();
          case 'Home':
            event.preventDefault();
            return setPreselected(values[0]);
          case 'End':
            event.preventDefault();
            return setPreselected(values[values.length - 1]);
          default:
            break;
        }
      }
    };
    const rootDocument = isEnvironment('browser') ? refs.root.current?.ownerDocument || window.document : undefined;
    rootDocument.addEventListener('keydown', onKeyDown);
    return () => {
      MENUS.remove(refs.id.current);
      rootDocument.removeEventListener('keydown', onKeyDown);
    };
  }, []);
  React.useEffect(() => {
    if (open) {
      if (autoSelect) {
        const values = React.Children.toArray(refs.props.current.children).map((item, index) => (item.props?.button || item.props?.href) && !item.props?.disabled ? index : undefined).filter(item => is('number', item));
        setPreselected(values[0]);
      }
    }
    setTimeout(() => {
      if (include && refs.root.current) include.push(refs.root.current);
    });
    return () => {
      if (include) {
        const index = include.findIndex(item => item === refs.root.current);
        if (index > -1) include.splice(index, 1);
      }
    };
  }, [open]);
  React.useEffect(() => {
    if (open !== open_) setOpen(open_);
  }, [open_]);
  const onMouseLeave = React.useCallback(() => {
    setPreselected('');
  }, []);
  const onOpen = () => {
    if (open_ === undefined) setOpen(true);
    if (is('function', onOpen_)) onOpen_();
  };
  const onClose = () => {
    if (open_ === undefined) setOpen(false);
    if (refs.props.current.autoSelectOnBlur) {
      const item = React.Children.toArray(refs.props.current.children)[refs.preselected.current];
      if (item && is('function', refs.props.current.onSelect)) refs.props.current.onSelect(item.props?.value !== undefined ? item.props?.value : item.props?.primary);
    }
    setPreselected('');
    if (is('function', onClose_)) onClose_();
  };
  const Wrapper = closeOnClickAway ? ClickListener : React.Fragment;
  let WrapperProps = _objectSpread({}, WrapperProps_);
  if (closeOnClickAway) {
    WrapperProps.onClickOutside = onClose;
    WrapperProps.include = [refs.main.current, ...(refs.include.current || []), ...include].filter(Boolean);
    WrapperProps.includeParentQueries = [...includeParentQueries, `.${refs.menuClassName.current}`];
    WrapperProps.includeQueries = [...includeQueries, `.${refs.menuClassName.current}`];
    WrapperProps.ignoreNonExisting = ignoreNonExisting;
    WrapperProps = _objectSpread(_objectSpread({}, WrapperProps), ClickListenerProps);
  }
  if (open) MENUS.add(id);else MENUS.remove(id);
  const methodItem = (item, index) => _objectSpread({
    key: item.key || index,
    role: 'menuitem',
    menuId: id,
    MenuProps: _objectSpread(_objectSpread({}, item.props?.MenuProps), {}, {
      className: classNames([item.props?.MenuProps?.className, refs.menuClassName.current])
    }),
    onClose
  }, (item.props?.button || item.props?.href) && !item.props.disabled ? {
    onMouseEnter: () => {
      setPreselected(index);
    },
    onMouseLeave: () => {
      setPreselected('');
    },
    preselected: index === preselected,
    onClick: event => {
      if (is('function', item.props?.onClick)) item.props?.onClick(event);
      if (item.props?.menuCloseOnClick) onClose();
    },
    onKeyDown: event => {
      if (event.target === event.currentTarget && event.key === 'Enter') {
        if (is('function', item.props?.onClick)) item.props?.onClick();
        if (is('function', item.props?.onKeyDown)) item.props?.onKeyDown(event);
        if (item.props?.menuCloseOnClick) onClose();
      }
    }
  } : {});
  const nameValue = name || label;
  return /*#__PURE__*/React.createElement(Wrapper, WrapperProps, /*#__PURE__*/React.createElement(Tooltip, _extends({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    },
    open: open,
    className: classNames([staticClassName('Menu', theme) && ['onesy-Menu-root', open && `onesy-Menu-open`], className, classes.root]),
    onMouseLeave: onMouseLeave,
    anchor: anchor,
    anchorElement: anchorElement,
    label: nameValue ? is('function', nameValue) ? nameValue(methodItem) : nameValue : menuItems && /*#__PURE__*/React.createElement(List, _extends({
      menu: true,
      menuOpen: open,
      include: refs.include.current,
      role: "menu"
    }, ListProps), ListProps?.noChildrenTransform ? menuItems : React.Children.toArray(menuItems).map((item, index) => (/*#__PURE__*/React.cloneElement(item, methodItem(item, index))))),
    click: true,
    arrow: arrow,
    hover: false,
    focus: false,
    longPress: false,
    noMargin: !arrow,
    onOpen: onOpen,
    onClose: onClose,
    ModalProps: _objectSpread({
      background: true,
      backgroundInvisible: true,
      freezeScroll: false
    }, ModalProps)
  }, other), children && /*#__PURE__*/React.cloneElement(children, {
    ref: item => {
      if (children.ref) {
        if (is('function', children.ref)) children.ref(item);else children.ref.current = item;
      }
      refs.main.current = item;
    }
  })));
});
Menu.displayName = 'onesy-Menu';
export default Menu;

==> ui-react-1.1.440.tgz: package/esm/Menu/Menu.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["open", "openDefault", "name", "label", "menuItems", "arrow", "anchor", "anchorElement", "autoSelect", "autoSelectOnBlur", "resetKeyboardNavigation", "closeOnClickAway", "include", "includeParentQueries", "includeQueries", "ignoreNonExisting", "onSelect", "onOpen", "onClose", "ListProps", "ModalProps", "WrapperProps", "ClickListenerProps", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { is, isEnvironment } from '@amaui/utils';
import { style as styleMethod, classNames, useAmauiTheme } from '@amaui/style-react';
import ListElement from '../List';
import TooltipElement from '../Tooltip';
import ClickListenerElement from '../ClickListener';
import { staticClassName } from '../utils';
const useStyle = styleMethod(theme => ({
  root: {}
}), {
  name: 'amaui-Menu'
});
export const MENUS = {
  open: [],
  priority: value => MENUS.open[MENUS.open.length - 1] === value,
  add: value => {
    const index = MENUS.open.findIndex(item => item === value);
    if (index === -1) MENUS.open.push(value);
    MENUS.open = MENUS.open.filter(Boolean);
  },
  remove: value => {
    const index = MENUS.open.findIndex(item => item === value);
    if (index > -1) MENUS.open.splice(index, 1);
    MENUS.open = MENUS.open.filter(Boolean);
  }
};
const Menu = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiMenu?.props?.default), props_), [props_]);
  const List = React.useMemo(() => theme?.elements?.List || ListElement, [theme]);
  const Tooltip = React.useMemo(() => theme?.elements?.Tooltip || TooltipElement, [theme]);
  const ClickListener = React.useMemo(() => theme?.elements?.ClickListener || ClickListenerElement, [theme]);
  const {
      open: open_,
      openDefault,
      name,
      label,
      menuItems,
      arrow,
      anchor,
      anchorElement,
      autoSelect,
      autoSelectOnBlur,
      resetKeyboardNavigation = false,
      closeOnClickAway = true,
      include = [],
      includeParentQueries = [],
      includeQueries = [],
      ignoreNonExisting,
      onSelect,
      onOpen: onOpen_,
      onClose: onClose_,
      ListProps,
      ModalProps,
      WrapperProps: WrapperProps_,
      ClickListenerProps,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const id = React.useId();
  const [open, setOpen] = React.useState(openDefault !== undefined ? openDefault : open_);
  const [preselected, setPreselected] = React.useState();
  const refs = {
    root: React.useRef(),
    id: React.useRef(),
    main: React.useRef(),
    props: React.useRef(),
    preselected: React.useRef(),
    include: React.useRef([]),
    menuClassName: React.useRef(`a-${new Date().getTime()}`)
  };
  refs.id.current = id;
  refs.preselected.current = preselected;
  refs.props.current = props;
  React.useEffect(() => {
    if (open) {
      MENUS.add(refs.id.current);
      if (autoSelect) {
        const values = React.Children.toArray(refs.props.current.children).map((item, index) => (item.props?.button || item.props?.href) && !item.props?.disabled ? index : undefined).filter(item => is('number', item));
        setPreselected(values[0]);
      }
    }
    const onKeyDown = event => {
      if (refs.props.current.open && MENUS.priority(refs.id.current)) {
        const values = React.Children.toArray(refs.props.current.children).map((item, index) => (item.props?.button || item.props?.href) && !item.props?.disabled ? index : undefined).filter(item => is('number', item));
        switch (event.key) {
          case 'ArrowUp':
            event.preventDefault();
            return setPreselected(() => {
              let value = refs.preselected.current;
              const index = values.findIndex(item_ => item_ === value);
              if (index === -1) value = values[values.length - 1];else if (index > 0) value = values[index - 1];else if (refs.props.current.resetKeyboardNavigation) value = values[values.length - 1];
              return value;
            });
          case 'ArrowDown':
            event.preventDefault();
            return setPreselected(() => {
              let value = refs.preselected.current;
              const index = values.findIndex(item_ => item_ === value);
              if (index === -1) value = values[0];else if (index < values.length - 1) value = values[index + 1];else if (refs.props.current.resetKeyboardNavigation) value = values[0];
              return value;
            });
          case 'Escape':
            event.preventDefault();
            return onClose();
          case 'Home':
            event.preventDefault();
            return setPreselected(values[0]);
          case 'End':
            event.preventDefault();
            return setPreselected(values[values.length - 1]);
          default:
            break;
        }
      }
    };
    const rootDocument = isEnvironment('browser') ? refs.root.current?.ownerDocument || window.document : undefined;
    rootDocument.addEventListener('keydown', onKeyDown);
    return () => {
      MENUS.remove(refs.id.current);
      rootDocument.removeEventListener('keydown', onKeyDown);
    };
  }, []);
  React.useEffect(() => {
    if (open) {
      if (autoSelect) {
        const values = React.Children.toArray(refs.props.current.children).map((item, index) => (item.props?.button || item.props?.href) && !item.props?.disabled ? index : undefined).filter(item => is('number', item));
        setPreselected(values[0]);
      }
    }
    setTimeout(() => {
      if (include && refs.root.current) include.push(refs.root.current);
    });
    return () => {
      if (include) {
        const index = include.findIndex(item => item === refs.root.current);
        if (index > -1) include.splice(index, 1);
      }
    };
  }, [open]);
  React.useEffect(() => {
    if (open !== open_) setOpen(open_);
  }, [open_]);
  const onMouseLeave = React.useCallback(() => {
    setPreselected('');
  }, []);
  const onOpen = () => {
    if (open_ === undefined) setOpen(true);
    if (is('function', onOpen_)) onOpen_();
  };
  const onClose = () => {
    if (open_ === undefined) setOpen(false);
    if (refs.props.current.autoSelectOnBlur) {
      const item = React.Children.toArray(refs.props.current.children)[refs.preselected.current];
      if (item && is('function', refs.props.current.onSelect)) refs.props.current.onSelect(item.props?.value !== undefined ? item.props?.value : item.props?.primary);
    }
    setPreselected('');
    if (is('function', onClose_)) onClose_();
  };
  const Wrapper = closeOnClickAway ? ClickListener : React.Fragment;
  let WrapperProps = _objectSpread({}, WrapperProps_);
  if (closeOnClickAway) {
    WrapperProps.onClickOutside = onClose;
    WrapperProps.include = [refs.main.current, ...(refs.include.current || []), ...include].filter(Boolean);
    WrapperProps.includeParentQueries = [...includeParentQueries, `.${refs.menuClassName.current}`];
    WrapperProps.includeQueries = [...includeQueries, `.${refs.menuClassName.current}`];
    WrapperProps.ignoreNonExisting = ignoreNonExisting;
    WrapperProps = _objectSpread(_objectSpread({}, WrapperProps), ClickListenerProps);
  }
  if (open) MENUS.add(id);else MENUS.remove(id);
  const methodItem = (item, index) => _objectSpread({
    key: item.key || index,
    role: 'menuitem',
    menuId: id,
    MenuProps: _objectSpread(_objectSpread({}, item.props?.MenuProps), {}, {
      className: classNames([item.props?.MenuProps?.className, refs.menuClassName.current])
    }),
    onClose
  }, (item.props?.button || item.props?.href) && !item.props.disabled ? {
    onMouseEnter: () => {
      setPreselected(index);
    },
    onMouseLeave: () => {
      setPreselected('');
    },
    preselected: index === preselected,
    onClick: event => {
      if (is('function', item.props?.onClick)) item.props?.onClick(event);
      if (item.props?.menuCloseOnClick) onClose();
    },
    onKeyDown: event => {
      if (event.target === event.currentTarget && event.key === 'Enter') {
        if (is('function', item.props?.onClick)) item.props?.onClick();
        if (is('function', item.props?.onKeyDown)) item.props?.onKeyDown(event);
        if (item.props?.menuCloseOnClick) onClose();
      }
    }
  } : {});
  const nameValue = name || label;
  return /*#__PURE__*/React.createElement(Wrapper, WrapperProps, /*#__PURE__*/React.createElement(Tooltip, _extends({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      refs.root.current = item;
    },
    open: open,
    className: classNames([staticClassName('Menu', theme) && ['amaui-Menu-root', open && `amaui-Menu-open`], className, classes.root]),
    onMouseLeave: onMouseLeave,
    anchor: anchor,
    anchorElement: anchorElement,
    label: nameValue ? is('function', nameValue) ? nameValue(methodItem) : nameValue : menuItems && /*#__PURE__*/React.createElement(List, _extends({
      menu: true,
      menuOpen: open,
      include: refs.include.current,
      role: "menu"
    }, ListProps), ListProps?.noChildrenTransform ? menuItems : React.Children.toArray(menuItems).map((item, index) => /*#__PURE__*/React.cloneElement(item, methodItem(item, index)))),
    click: true,
    arrow: arrow,
    hover: false,
    focus: false,
    longPress: false,
    noMargin: !arrow,
    onOpen: onOpen,
    onClose: onClose,
    ModalProps: _objectSpread({
      background: true,
      backgroundInvisible: true,
      freezeScroll: false
    }, ModalProps)
  }, other), children && /*#__PURE__*/React.cloneElement(children, {
    ref: item => {
      if (children.ref) {
        if (is('function', children.ref)) children.ref(item);else children.ref.current = item;
      }
      refs.main.current = item;
    }
  })));
});
Menu.displayName = 'amaui-Menu';
export default Menu;
